![Logo Couleur West IT](https://github.com/couleurwest-it/dreamgeeker-tools/blob/main/logo.png)

# Dreamtools

**Librairies de fonctions aide au développement**

Vous pouvez télécharger depuis notre dépôt Github:  [Dreamtools](https://github.com/couleurwest/pypi/dreamgeeker-tools)

[Lire la documentation](https://couleurwest-it.com/dreamtools) | [Télécharger documentation](https://github.com/couleurwest/dreamgeeker-tools/raw/main/docs/build/pdf/dreamtools.pdf)


## Paquets dépendants

**Environnement Python 3.8**

* cerberus
* pyaml
* pillow 
* pycrypt *(Module Krypt uniquement sous Linux)*
* requests

## Installation

<pre>
$ pip install [--upgrade] dreamtools-dreamgeeker
$ tools-installer
</pre>

## Configuration

<pre>
import dreamtools

dreamtools.config(appname='project', mode='prod')  # Utilise les information contenu dans .ENV MODE DEVELOPMENT ou PRODUCTION | PROJECT_NAME
</pre>

# Informations 

## Génération documentation

* html : sphinx
* pdf : rinohtype

## Couleur West IT
[Conception & Réalisation de solutions numériques adaptées](https://couleurwest-it.com)

*Accompagement au changement*

### Un conseil, un avis, une expertises 
[Ecrivez-nous par mail](mailto://contact@couleurwest-it.com) | [Par Telegram](https://t.me/dreamgeeker)


*By dreamgeeker &copy; 2020 Couleur West IT*
